.. _user_guide:

User Guide
==========

Skrub is a Python library that facilitates machine learning with tabular data
(dataframes, as with pandas and polars) using a scikit-learn–compatible API.

Use the sections below to navigate the guide. For runnable code, see the
:doc:`Example gallery <auto_examples/index>`. For class and function details, see
the :ref:`API Reference <api_ref>`.


.. include:: includes/big_toc_css.rst

.. toctree::
   :maxdepth: 3

   exploring_a_dataframe
   default_wrangling
   column_level_featurizing
   multi_column_operations
   data_ops
   configuration_and_utils
   joining_dataframes
